# Sidd-Package
Siddhartha's resume in the form of python-package 

## Directory stracture

    │   .gitignore
    │   LICENSE
    │   README.md
    │   setup.py
    │
    └───sidd
        │   sidd.py
        │   __init__.py
        │
        ├───bye
        │       bye.py
        │       __init__.py
        │
        ├───contact
        │       contact.py
        │       __init__.py
        │
        ├───education
        │       education.py
        │       __init__.py
        │
        ├───experience
        │       experience.py
        │       __init__.py
        │
        ├───hello
        │       hello.py
        │       __init__.py
        │
        └───project
                project.py
                __init__.py


## Run Locally


Install package
```py
  pip install siddp6
```

Import package
```py
  import sidd
```

Print all attributes and methods (functions , modules, strings, lists, dictionaries etc.)
```py
  print(dir(sidd))
```

## Output

<img width="959" alt="image" src="https://user-images.githubusercontent.com/91800813/208263532-9fd01cc9-530b-4758-b5e5-ac364ecc3722.png">


## Tech & Tool

__Language__: [Python](https://www.python.org/)
